@@ -2,6 +2,7 @@
 
 import io
 import os
+import sys
 import array
 import tempfile
 import struct
@@ -10,6 +11,15 @@ import cairo
 import pytest
 
 
+def test_image_surface_get_data_refcount():
+    surface = cairo.ImageSurface(cairo.FORMAT_ARGB32, 10, 10)
+    assert sys.getrefcount(surface) == 2
+    d = surface.get_data()
+    assert sys.getrefcount(surface) == 3
+    del d
+    assert sys.getrefcount(surface) == 2
+
+
 def test_surface_get_content():
     surface = cairo.ImageSurface(cairo.FORMAT_ARGB32, 10, 10)
     assert surface.get_content() == cairo.Content.COLOR_ALPHA
